@@ -1,4 +1,5 @@
 from os import environ
+from os.path import expanduser
 from sys import argv
 
 from setux.targets import Local, SSH
@@ -10,7 +11,7 @@ from .usage import usage
 
 def get_target(name=None, dest=None):
     name = name or environ.get('setux_target')
-    dest = dest or environ.get('setux_outdir', '/var/log/setux')
+    dest = dest or environ.get('setux_outdir', expanduser('~/setux'))
     if name:
         try:
             target = SSH(name=name, host=name, outdir=dest)
